@@ -16,6 +16,15 @@ class APIWrapper(object):
         self._conn = connection
         self._executor = executor
 
+    @property
+    def conn(self):
+        """Return HTTP connection object.
+
+        :return: HTTP connection.
+        :rtype: arango.connection.Connection
+        """
+        return self._conn
+
     @property
     def db_name(self):
         """Return the name of the current database.
