@@ -1,7 +1,5 @@
 from __future__ import absolute_import, unicode_literals
 
-from six import string_types
-
 __all__ = [
     'DefaultExecutor',
     'AsyncExecutor',
@@ -12,17 +10,20 @@ __all__ = [
 from collections import OrderedDict
 from uuid import uuid4
 
+from six import moves
+
 from arango.exceptions import (
     AsyncExecuteError,
     BatchStateError,
     BatchExecuteError,
-    TransactionStateError,
-    TransactionExecuteError,
+    TransactionAbortError,
+    TransactionCommitError,
+    TransactionStatusError,
+    TransactionInitError
 )
 from arango.job import (
     AsyncJob,
-    BatchJob,
-    TransactionJob
+    BatchJob
 )
 from arango.request import Request
 from arango.response import Response
@@ -77,8 +78,8 @@ class DefaultExecutor(Executor):
         :return: API execution result.
         :rtype: str | unicode | bool | int | list | dict
         """
-        response = self._conn.send_request(request)
-        return response_handler(response)
+        resp = self._conn.send_request(request)
+        return response_handler(resp)
 
 
 class AsyncExecutor(Executor):
@@ -143,6 +144,24 @@ class BatchExecutor(Executor):
         self._queue = OrderedDict()
         self._committed = False
 
+    # noinspection PyMethodMayBeStatic,PyUnresolvedReferences
+    def _stringify_request(self, request):
+        path = request.endpoint
+
+        if request.params is not None:
+            path += '?' + moves.urllib.parse.urlencode(request.params)
+        buffer = ['{} {} HTTP/1.1'.format(request.method, path)]
+
+        if request.headers is not None:
+            for key, value in sorted(request.headers.items()):
+                buffer.append('{}: {}'.format(key, value))
+
+        if request.data is not None:
+            serialized = self._conn.serialize(request.data)
+            buffer.append('\r\n' + serialized)
+
+        return '\r\n'.join(buffer)
+
     @property
     def jobs(self):
         """Return the queued batch jobs.
@@ -191,8 +210,8 @@ class BatchExecutor(Executor):
         """
         if self._committed:
             raise BatchStateError('batch already committed')
-
-        self._committed = True
+        else:
+            self._committed = True
 
         if len(self._queue) == 0:
             return self.jobs
@@ -200,13 +219,13 @@ class BatchExecutor(Executor):
         # Boundary used for multipart request
         boundary = uuid4().hex
 
-        # Buffer for building the batch request payload
+        # Build the batch request payload
         buffer = []
         for req, job in self._queue.values():
             buffer.append('--{}'.format(boundary))
             buffer.append('Content-Type: application/x-arango-batchpart')
             buffer.append('Content-Id: {}'.format(job.id))
-            buffer.append('\r\n{}'.format(req))
+            buffer.append('\r\n' + self._stringify_request(req))
         buffer.append('--{}--'.format(boundary))
 
         request = Request(
@@ -216,7 +235,7 @@ class BatchExecutor(Executor):
                 'Content-Type':
                     'multipart/form-data; boundary={}'.format(boundary)
             },
-            data='\r\n'.join(buffer)
+            data='\r\n'.join(buffer),
         )
         with suppress_warning('requests.packages.urllib3.connectionpool'):
             resp = self._conn.send_request(request)
@@ -227,7 +246,9 @@ class BatchExecutor(Executor):
         if not self._return_result:
             return None
 
+        url_prefix = resp.url.strip('/_api/batch')
         raw_resps = resp.raw_body.split('--{}'.format(boundary))[1:-1]
+
         if len(self._queue) != len(raw_resps):
             raise BatchStateError(
                 'expecting {} parts in batch response but got {}'
@@ -244,15 +265,17 @@ class BatchExecutor(Executor):
 
             # Update the corresponding batch job
             queued_req, queued_job = self._queue[job_id]
-            queued_job._response = Response(
+
+            queued_job._status = 'done'
+            resp = Response(
                 method=queued_req.method,
-                url=self._conn.url_prefix + queued_req.endpoint,
+                url=url_prefix + queued_req.endpoint,
                 headers={},
                 status_code=int(status_code),
                 status_text=status_text,
                 raw_body=raw_body
             )
-            queued_job._status = 'done'
+            queued_job._response = self._conn.prep_response(resp)
 
         return self.jobs
 
@@ -262,158 +285,140 @@ class TransactionExecutor(Executor):
 
     :param connection: HTTP connection.
     :type connection: arango.connection.Connection
-    :param return_result: If set to True, API executions return instances of
-        :class:`arango.job.TransactionJob` that are populated with results on
-        commit. If set to False, API executions return None and no results are
-        tracked client-side.
-    :type return_result: bool
-    :param timeout: Timeout for waiting on collection locks. If set to 0,
-        ArangoDB server waits indefinitely. If not set, system default value
-        is used.
-    :type timeout: int
+    :param read: Name(s) of collections read during transaction. Read-only
+        collections are added lazily but should be declared if possible to
+        avoid deadlocks.
+    :type read: str | unicode | [str | unicode]
+    :param write: Name(s) of collections written to during transaction with
+        shared access.
+    :type write: str | unicode | [str | unicode]
+    :param exclusive: Name(s) of collections written to during transaction
+        with exclusive access.
+    :type exclusive: str | unicode | [str | unicode]
     :param sync: Block until operation is synchronized to disk.
     :type sync: bool
-    :param read: Names of collections read during transaction.
-    :type read: [str | unicode]
-    :param write: Names of collections written to during transaction.
-    :type write: [str | unicode]
+    :param allow_implicit: Allow reading from undeclared collections.
+    :type allow_implicit: bool
+    :param lock_timeout: Timeout for waiting on collection locks. If not given,
+        a default value is used. Setting it to 0 disables the timeout.
+    :type lock_timeout: int
+    :param max_size: Max transaction size in bytes. Applicable to RocksDB
+        storage engine only.
+    :type max_size: int
     """
     context = 'transaction'
 
-    def __init__(self, connection, return_result, read, write, timeout, sync):
+    def __init__(self,
+                 connection,
+                 read=None,
+                 write=None,
+                 exclusive=None,
+                 sync=None,
+                 allow_implicit=None,
+                 lock_timeout=None,
+                 max_size=None):
         super(TransactionExecutor, self).__init__(connection)
-        self._return_result = return_result
-        self._read = read
-        self._write = write
-        self._timeout = timeout
-        self._sync = sync
-        self._queue = OrderedDict()
-        self._committed = False
+
+        collections = {}
+        if read is not None:
+            collections['read'] = read
+        if write is not None:
+            collections['write'] = write
+        if exclusive is not None:
+            collections['exclusive'] = exclusive
+
+        data = {'collections': collections}
+        if sync is not None:
+            data['waitForSync'] = sync
+        if allow_implicit is not None:
+            data['allowImplicit'] = allow_implicit
+        if lock_timeout is not None:
+            data['lockTimeout'] = lock_timeout
+        if max_size is not None:
+            data['maxTransactionSize'] = max_size
+
+        request = Request(
+            method='post',
+            endpoint='/_api/transaction/begin',
+            data=data
+        )
+        resp = self._conn.send_request(request)
+
+        if not resp.is_success:
+            raise TransactionInitError(resp, request)
+
+        self._id = resp.body['result']['id']
 
     @property
-    def jobs(self):
-        """Return the queued transaction jobs.
+    def id(self):
+        """Return the transaction ID.
 
-        :return: Transaction jobs or None if **return_result** parameter was
-            set to False during initialization.
-        :rtype: [arango.job.TransactionJob] | None
+        :return: Transaction ID.
+        :rtype: str | unicode
         """
-        if not self._return_result:
-            return None
-        return [job for _, job in self._queue.values()]
+        return self._id
 
     def execute(self, request, response_handler):
-        """Place the request in the transaction queue.
+        """Execute API request in a transaction and return the result.
 
         :param request: HTTP request.
         :type request: arango.request.Request
         :param response_handler: HTTP response handler.
         :type response_handler: callable
-        :return: Transaction job or None if **return_result** parameter was
-            set to False during initialization.
-        :rtype: arango.job.TransactionJob | None
-        :raise arango.exceptions.TransactionStateError: If the transaction was
-            already committed or if the action does not support transactions.
+        :return: API execution result.
+        :rtype: str | unicode | bool | int | list | dict
         """
-        if self._committed:
-            raise TransactionStateError('transaction already committed')
-        if request.command is None:
-            raise TransactionStateError('action not allowed in transaction')
+        request.headers['x-arango-trx-id'] = self._id
+        resp = self._conn.send_request(request)
+        return response_handler(resp)
 
-        job = TransactionJob(response_handler)
-        self._queue[job.id] = (request, job)
-        return job if self._return_result else None
+    def status(self):
+        """Return the transaction status.
 
-    def commit(self):
-        """Execute the queued requests in a single transaction API request.
-
-        If **return_result** parameter was set to True during initialization,
-        :class:`arango.job.TransactionJob` instances are populated with
-        results.
-
-        :return: Transaction jobs or None if **return_result** parameter was
-            set to False during initialization.
-        :rtype: [arango.job.TransactionJob] | None
-        :raise arango.exceptions.TransactionStateError: If the transaction was
-            already committed.
-        :raise arango.exceptions.TransactionExecuteError: If commit fails.
+        :return: Transaction status.
+        :rtype: str | unicode
+        :raise arango.exceptions.TransactionStatusError: If retrieval fails.
         """
-        if self._committed:
-            raise TransactionStateError('transaction already committed')
-
-        self._committed = True
-
-        if len(self._queue) == 0:
-            return self.jobs
-
-        write_collections = set()
-        if isinstance(self._write, string_types):
-            write_collections.add(self._write)
-        elif self._write is not None:
-            write_collections |= set(self._write)
-
-        read_collections = set()
-        if isinstance(self._read, string_types):
-            read_collections.add(self._read)
-        elif self._read is not None:
-            read_collections |= set(self._read)
-
-        # Buffer for building the transaction javascript command
-        cmd_buffer = [
-            'var db = require("internal").db',
-            'var gm = require("@arangodb/general-graph")',
-            'var result = {}'
-        ]
-        for req, job in self._queue.values():
-            if isinstance(req.read, string_types):
-                read_collections.add(req.read)
-            elif req.read is not None:
-                read_collections |= set(req.read)
-
-            if isinstance(req.write, string_types):
-                write_collections.add(req.write)
-            elif req.write is not None:
-                write_collections |= set(req.write)
-
-            cmd_buffer.append('result["{}"] = {}'.format(job.id, req.command))
-
-        cmd_buffer.append('return result;')
-
-        data = {
-            'action': 'function () {{ {} }}'.format(';'.join(cmd_buffer)),
-            'collections': {
-                'read': list(read_collections),
-                'write': list(write_collections),
-                'allowImplicit': True
-            }
-        }
-        if self._timeout is not None:
-            data['lockTimeout'] = self._timeout
-        if self._sync is not None:
-            data['waitForSync'] = self._sync
-
         request = Request(
-            method='post',
-            endpoint='/_api/transaction',
-            data=data,
+            method='get',
+            endpoint='/_api/transaction/{}'.format(self._id),
         )
         resp = self._conn.send_request(request)
 
-        if not resp.is_success:
-            raise TransactionExecuteError(resp, request)
+        if resp.is_success:
+            return resp.body['result']['status']
+        raise TransactionStatusError(resp, request)
 
-        if not self._return_result:
-            return None
+    def commit(self):
+        """Commit the transaction.
 
-        result = resp.body['result']
-        for req, job in self._queue.values():
-            job._response = Response(
-                method=req.method,
-                url=self._conn.url_prefix + req.endpoint,
-                headers={},
-                status_code=200,
-                status_text='OK',
-                raw_body=result.get(job.id)
-            )
-            job._status = 'done'
-        return self.jobs
+        :return: True if commit was successful.
+        :rtype: bool
+        :raise arango.exceptions.TransactionCommitError: If commit fails.
+        """
+        request = Request(
+            method='put',
+            endpoint='/_api/transaction/{}'.format(self._id),
+        )
+        resp = self._conn.send_request(request)
+
+        if resp.is_success:
+            return True
+        raise TransactionCommitError(resp, request)
+
+    def abort(self):
+        """Abort the transaction.
+
+        :return: True if the abort operation was successful.
+        :rtype: bool
+        :raise arango.exceptions.TransactionAbortError: If abort fails.
+        """
+        request = Request(
+            method='delete',
+            endpoint='/_api/transaction/{}'.format(self._id),
+        )
+        resp = self._conn.send_request(request)
+
+        if resp.is_success:
+            return True
+        raise TransactionAbortError(resp, request)
